package com.persagy.dmp.digital.client;

import cn.hutool.extra.spring.SpringUtil;
import com.persagy.dmp.basic.dto.RequestData;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ResultHelper;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

/**
 * 数字孪生 简洁API Client门面
 * @author Charlie Yu
 * @date 2021-05-15
 */
public class DigitalObjectSimpleFacade {

    private static DigitalObjectSimpleClient client = SpringUtil.getBean(DigitalObjectSimpleClient.class);

    /**
     * 根据项目ID查询设备数量和待报废设备数量统计
     * @param groupCode: 集团编码
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param projectIds: 项目ID - 为空查所有
     * @return
     */
    public static List<Map<String, Object>> queryExpectScrapCountByProjects(@RequestParam("groupCode") String groupCode,
                                                                            @RequestParam("appId") String appId,
                                                                            @RequestParam("userId") String userId,
                                                                            @RequestBody(required = false) List<String> projectIds) {
        CommonResult<List<Map<String, Object>>> result = client.queryExpectScrapCountByProjects(groupCode, appId, userId, projectIds);
        return ResultHelper.getContent(result);
    }
    /**
     * 根据对象信息点统计数量
     * @param groupCode: 集团编码
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param requestData: 请求参数
     * @return
     */
    public static List<Map<String, Object>> queryObjectCountByObjInfos(String groupCode, String appId, String userId, RequestData requestData) {
        CommonResult<List<Map<String, Object>>> result = client.queryObjectCountByObjInfos(groupCode, appId, userId, requestData);
        return ResultHelper.getContent(result);
    }
}
